@@ -3,7 +3,7 @@
 #############################################################################
 ##
 ##   Release build script
-##   Last updated on April 11, 2025
+##   Last updated on May 11, 2025
 ##
 ##   This file is part of Logtalk <https://logtalk.org/>
 ##   SPDX-FileCopyrightText: 1998-2025 Paulo Moura <pmoura@logtalk.org>
@@ -102,14 +102,15 @@ chmod a+x scripts/cleandist.sh
 scripts/cleandist.sh
 cd ..
 
-# Ensure that the Handbook and APIs documentation is up-to-date
-"logtalk-$version"/manuals/sources/build_manuals.sh
-"logtalk-$version"/scripts/update_html_docs.sh
-
 # Build manuals archive if enabled
 if [ "$BUILD_MANUALS" = true ]; then
     echo "Building manuals archive..."
-    cp -R "logtalk-$version/manuals" "logtalk-manuals-$version"
+	# Ensure that the Handbook and APIs documentation is up-to-date
+	# and all output formats are generated
+	"logtalk-$version"/docs/handbook/sources/build.sh
+	"logtalk-$version"/docs/apis/sources/build.sh
+	"logtalk-$version"/docs/apis/sources/update_svg_diagrams.sh
+    cp -R "logtalk-$version/docs" "logtalk-manuals-$version"
     tar -czf "logtalk-manuals-$version.tgz" "logtalk-manuals-$version"
 else
     echo "Skipping manuals archive build."
@@ -171,8 +172,8 @@ if [ "$BUILD_DEB" = true ]; then
     cp debian/control "$directory/debian/DEBIAN"
     # Use appropriate sed syntax based on the system
     case $(sed --help 2>&1) in
-        *GNU*) sudo sed -i "s/^Version:.*/Version: $version/" "$directory/debian/DEBIAN/control" ;;
-        *) sudo sed -i '' "s/^Version:.*/Version: $version/" "$directory/debian/DEBIAN/control" ;;
+        *GNU*) sed -i "s/^Version:.*/Version: $version/" "$directory/debian/DEBIAN/control" ;;
+        *) sed -i '' "s/^Version:.*/Version: $version/" "$directory/debian/DEBIAN/control" ;;
     esac
     cp debian/postinst "$directory/debian/DEBIAN"
     cp debian/prerm "$directory/debian/DEBIAN"
@@ -233,10 +234,24 @@ fi
 cd "$directory" || exit 1
 
 openssl sha256 logtalk-$version.tar.bz2 || true
-openssl sha256 logtalk-$version.pkg.zip || true
-openssl sha256 logtalk-$version-1.noarch.rpm || true
-openssl sha256 logtalk_$version-1_all.deb || true
-openssl sha256 logtalk-manuals-$version.tgz || true
-openssl sha256 logtalk-$version.exe || true
-openssl sha256 logtalk-$version.tgz || true
-openssl sha256 logtalk-experimental-$version.tgz || true
+if [ "$BUILD_PKG" = true ]; then
+	openssl sha256 logtalk-$version.pkg.zip || true
+fi
+if [ "$BUILD_RPM" = true ]; then
+	openssl sha256 logtalk-$version-1.noarch.rpm || true
+fi
+if [ "$BUILD_DEB" = true ]; then
+	openssl sha256 logtalk_$version-1_all.deb || true
+fi
+if [ "$BUILD_MANUALS" = true ]; then
+	openssl sha256 logtalk-manuals-$version.tgz || true
+fi
+if [ -f "logtalk-$version.exe" ]; then
+	openssl sha256 logtalk-$version.exe || true
+fi
+if [ "$BUILD_PACK" = true ]; then
+	openssl sha256 logtalk-$version.tgz || true
+fi
+if [ "$BUILD_PACK_EXPERIMENTAL" = true ]; then
+	openssl sha256 logtalk-experimental-$version.tgz || true
+fi
